--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
-- mapinfo.lua
--
local mapinfo = {
	name = "Techno Lands Final v3.6",
	description = "",
	author = "8D",
	version = "",
	mapfile = "maps/techno_final.smf",
	modtype = 3, --// 1 = primary, 0 = hidden, 3 = map
	replace = {},
	maphardness = 100000,
	tidalStrength = 10,
	gravity = 120,
	maxMetal = 15,
	extractorRadius = 115,
	autoShowMetal = true,
	smf = {
		minheight = 15,
		maxheight = 100,
		smtFileName0 = "maps/techno_final.smt"
	},
	resources = {
		detailTex = "detailtex.bmp"
	},
	atmosphere = {
		minWind = 6,
		maxWind = 23,
		fogStart = 0.65,
		fogEnd = 1.0,
		fogColor = {0.5, 0.55, 0.61},
		sunColor = {0.42, 0.23, 0.1},
		skyColor = {0.5, 0.55, 0.61},
		skyDir = {0.0, 0.0, -1.0},
		--skyBox       = "",
		cloudDensity = 0.01,
		cloudColor = {1.0, 1.0, 1.0}
	},
	lighting = {
		--// dynsun
		sunStartAngle = 0.0,
		sunOrbitTime = 1440.0,
		sunDir = {1, 0.7, 1},
		--// unit & ground lighting
		groundAmbientColor = {0.49, 0.53, 0.55},
		groundDiffuseColor = {0.9, 0.9, 0.9},
		groundSpecularColor = {0.5, 0.5, 0.5},
		groundShadowDensity = 0.8,
		unitAmbientColor = {0.5, 0.55, 0.61},
		unitDiffuseColor = {1.2, 1.1, 1.0},
		unitSpecularColor = {0.3, 0.3, 0.3},
		unitShadowDensity = 0.8,
		specularExponent = 100.0
	},
	water = {
		planeColor = {0.53, 0.53, 0.56}
	},
	teams = {
		[0] = {
			startPos = {
				x = 0,
				z = 0
			}
		},
		[1] = {
			startPos = {
				x = 0,
				z = 0
			}
		}
	},
	terrainTypes = {
		[0] = {
			name = "Default",
			hardness = 1.0,
			receiveTracks = true,
			moveSpeeds = {
				tank = 1.1,
				kbot = 1.0,
				hover = 1.0,
				ship = 1.0
			}
		}
	}
}

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
-- Helper
local function lowerkeys(ta)
	local fix = {}

	for i, v in pairs(ta) do
		if (type(i) == "string") and (i ~= i:lower()) then
			fix[#fix + 1] = i
		end

		if (type(v) == "table") then
			lowerkeys(v)
		end
	end

	for i = 1, #fix do
		local idx = fix[i]
		ta[idx:lower()] = ta[idx]
		ta[idx] = nil
	end
end

lowerkeys(mapinfo)

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
-- Map Options
if (Spring) then
	local function tmerge(t1, t2)
		for i, v in pairs(t2) do
			if (type(v) == "table") then
				t1[i] = t1[i] or {}
				tmerge(t1[i], v)
			else
				t1[i] = v
			end
		end
	end

	-- make code safe in unitsync
	if (not Spring.GetMapOptions) then
		Spring.GetMapOptions = function() return {} end
	end

	function tobool(val)
		local t = type(val)

		if (t == "nil") then
			return false
		elseif (t == "boolean") then
			return val
		elseif (t == "number") then
			return val ~= 0
		elseif (t == "string") then
			return (val ~= "0") and (val ~= "false")
		end

		return false
	end

	getfenv()["mapinfo"] = mapinfo
	local files = VFS.DirList("mapconfig/mapinfo/", "*.lua")
	table.sort(files)

	for i = 1, #files do
		local newcfg = VFS.Include(files[i])

		if newcfg then
			lowerkeys(newcfg)
			tmerge(mapinfo, newcfg)
		end
	end

	getfenv()["mapinfo"] = nil
end

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
return mapinfo
--------------------------------------------------------------------------------
--------------------------------------------------------------------------------