----------------------------------------------------------------------------------------------------------------------------------------------
----------------------------------------------------------------------------------------------------------------------------------------------
-- File:        MapOptions.lua
-- Description: Custom MapOptions file that makes possible to set up variable options before game starts, like ModOptions.lua
-- Author:      SirArtturi, Lurker, Smoth, jK
----------------------------------------------------------------------------------------------------------------------------------------------
----------------------------------------------------------------------------------------------------------------------------------------------
--NOTES:
--- using an enumerated table lets you specify the options order
--
--These keywords must be lowercase for LuaParser to read them.
--
--key:the string used in the script.txt
--name: the displayed name
--desc: the description (could be used as a tooltip)
--type: the option type
--def:the default value
--min:minimum value for number options
--max:maximum value for number options
--step: quantization step, aligned to the def value
--maxlen: the maximum string length for string options
--items:array of item strings for list options
--scope:'all', 'player', 'team', 'allyteam'<<< not supported yet >>>
--
--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
local options = {
    --// Sections
    {
        key = 'Terrain',
        name = 'Terrain Settings',
        desc = '',
        type = 'section'
    },
    {
        key = 'Economy',
        name = 'Economy Settings',
        desc = '',
        type = 'section'
    },
    {
        key = 'map_minwind',
        name = 'Min Wind Speed',
        desc = 'How strong wind will blow',
        type = 'number',
        section = 'Economy',
        def = 10,
        min = 0,
        max = 10000,
        step = 0.01
    },
    {
        key = 'map_maxwind',
        name = 'Max Wind Speed',
        desc = 'How strong wind will blow',
        type = 'number',
        section = 'Economy',
        def = 28,
        min = 0,
        max = 10000,
        step = 0.01
    },
    {
        key = 'map_metal',
        name = 'Metal Exctraction',
        desc = '',
        type = 'number',
        section = 'Economy',
        def = 2.5,
        min = 0,
        max = 20,
        step = 0.01
    },
    {
        key = 'map_maxheight',
        name = 'Map Max Height',
        desc = 'Min is 15, if set 15 map will be flat',
        type = 'number',
        section = 'Terrain',
        def = 100,
        min = 15,
        max = 1000,
        step = 1
    }
}

return options